"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk = require("chalk");
const path = require("path");
const CreateTsIndexOption_1 = require("../options/CreateTsIndexOption");
const CTILogger_1 = require("../tools/CTILogger");
const CommandModule_1 = require("./CommandModule");
class CleanCommandModule {
    do(passed) {
        return __awaiter(this, void 0, void 0, function* () {
            const option = CreateTsIndexOption_1.CreateTsIndexOption.factory({
                partialOption: passed,
            });
            const logger = new CTILogger_1.CTILogger(option);
            logger.log(chalk.default.yellowBright('Option: '), option);
            const cwd = option.globOptions.cwd;
            const indexFiles = yield CommandModule_1.CommandModule.promisify.glob('**/index.ts', {
                cwd,
                nonull: false,
            });
            const entrypointFiles = yield CommandModule_1.CommandModule.promisify.glob('**/entrypoint.ts', {
                cwd,
                nonull: false,
            });
            const concatted = indexFiles.concat(entrypointFiles);
            if (concatted.length === 0) {
                logger.flog(chalk.default.yellow(`Cannot find target file on working directory: ${cwd}`));
            }
            yield Promise.all(concatted.map((file) => {
                logger.log(chalk.default.redBright('delete file: '), path.join(cwd, file));
                return CommandModule_1.CommandModule.promisify.unlink(path.join(cwd, file));
            }));
            logger.flog(chalk.default.green(`clean succeeded: ${cwd}`));
        });
    }
}
exports.CleanCommandModule = CleanCommandModule;
//# sourceMappingURL=CleanCommandModule.js.map