#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk = require("chalk");
const fs = require("fs");
const path = require("path");
const yargs = require("yargs");
const CleanCommandModule_1 = require("./commands/CleanCommandModule");
const CreateCommandModule_1 = require("./commands/CreateCommandModule");
const EntrypointCommandModule_1 = require("./commands/EntrypointCommandModule");
const CreateTsIndexOption_1 = require("./options/CreateTsIndexOption");
const version = (() => {
    if (fs.existsSync(path.join(__dirname, 'package.json'))) {
        const packageJSON = JSON.parse(fs.readFileSync(path.join(__dirname, 'package.json')).toString());
        return packageJSON.version;
    }
    if (fs.existsSync(path.join('.', 'package.json'))) {
        const packageJSON = JSON.parse(fs.readFileSync(path.join('.', 'package.json')).toString());
        return packageJSON.version;
    }
    return '1.0.14';
})();
function yargOptionBuilder(args) {
    return args
        .option('filefirst', {
        alias: 'f',
        default: false,
        describe: 'export list create filefirst, no option false, option true',
        type: 'boolean',
    })
        .option('addnewline', {
        alias: 'n',
        default: true,
        describe: 'deside add newline file ending. no option true, option false',
        type: 'boolean',
    })
        .option('usesemicolon', {
        alias: 's',
        default: true,
        describe: 'deside use semicolon line ending. no option true, option false',
        type: 'boolean',
    })
        .option('includecwd', {
        alias: 'c',
        default: true,
        describe: 'deside include cwd directory in task. no option true, option false',
        type: 'boolean',
    })
        .option('usetimestamp', {
        alias: 't',
        default: false,
        describe: `deside use timestamp(YYYY-MM-DD HH:mm) top line comment.
no option false, option true`,
        type: 'boolean',
    })
        .option('excludes', {
        alias: 'e',
        array: true,
        default: ['@types', 'typings', '__test__', '__tests__', 'node_modules'],
        describe: `pass exclude directory. default exclude directory is
['@types', 'typings', '__test__', '__tests__']`,
        type: 'string',
    })
        .option('fileexcludes', {
        alias: 'i',
        array: true,
        default: [],
        describe: 'pass exclude pattern of filename. default exclude directory is "[]"',
        type: 'string',
    })
        .option('targetexts', {
        alias: 'x',
        array: true,
        default: ['ts', 'tsx'],
        describe: `pass include extname. default extname is ["ts", "tsx"]. extname
pass without dot charactor.`,
        type: 'string',
    })
        .option('verbose', {
        alias: 'v',
        default: false,
        describe: 'verbose logging message. to option false, option true',
        type: 'boolean',
    })
        .option('quote', {
        alias: 'q',
        default: "'",
        describe: "deside quote character. default quote character is '",
        type: 'string',
    });
}
yargs
    .command('$0 [cwds...]', 'create index.ts file in working directory', (args) => yargOptionBuilder(args), (args) => __awaiter(this, void 0, void 0, function* () {
    const cwds = args['cwds'];
    if (!cwds) {
        console.log(chalk.default.magenta('Enter working directory, '));
        console.log(chalk.default.red('cti [working directory]'));
        process.exit(1);
    }
    if (typeof cwds === 'string') {
        const createCommand = new CreateCommandModule_1.CreateCommandModule();
        const options = CreateTsIndexOption_1.CreateTsIndexOption.cliOptionBuilder(args, cwds);
        return createCommand.do(options);
    }
    if (typeof cwds !== 'string' && Array.isArray(cwds)) {
        return Promise.all(cwds
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const createCommand = new CreateCommandModule_1.CreateCommandModule();
            const options = CreateTsIndexOption_1.CreateTsIndexOption.cliOptionBuilder(args, cwd);
            return createCommand.do(options);
        }));
    }
}))
    .command('create [cwds...]', 'create index.ts file in working directory', (args) => yargOptionBuilder(args), (args) => __awaiter(this, void 0, void 0, function* () {
    const cwds = args['cwds'];
    if (!cwds) {
        console.log(chalk.default.magenta('Enter working directory, '));
        console.log(chalk.default.red('cti [working directory]'));
        process.exit(1);
    }
    if (typeof cwds === 'string') {
        const createCommand = new CreateCommandModule_1.CreateCommandModule();
        const options = CreateTsIndexOption_1.CreateTsIndexOption.cliOptionBuilder(args, cwds);
        return createCommand.do(options);
    }
    if (typeof cwds !== 'string' && Array.isArray(cwds)) {
        return Promise.all(cwds
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const createCommand = new CreateCommandModule_1.CreateCommandModule();
            const options = CreateTsIndexOption_1.CreateTsIndexOption.cliOptionBuilder(args, cwd);
            return createCommand.do(options);
        }));
    }
}))
    .command('entrypoint [cwds...]', 'create entrypoint.ts file in working directory', (args) => yargOptionBuilder(args), (args) => __awaiter(this, void 0, void 0, function* () {
    const cwds = args['cwds'];
    if (!cwds) {
        console.log(chalk.default.magenta('Enter working directory, '));
        console.log(chalk.default.red('cti [working directory]'));
        process.exit(1);
    }
    if (typeof cwds === 'string') {
        const entrypointCommand = new EntrypointCommandModule_1.EntrypointCommandModule();
        const options = CreateTsIndexOption_1.CreateTsIndexOption.cliOptionBuilder(args, cwds);
        entrypointCommand.do(options);
    }
    if (typeof cwds !== 'string' && Array.isArray(cwds)) {
        return Promise.all(cwds
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const entrypointCommand = new EntrypointCommandModule_1.EntrypointCommandModule();
            const options = CreateTsIndexOption_1.CreateTsIndexOption.cliOptionBuilder(args, cwd);
            return entrypointCommand.do(options);
        }));
    }
}))
    .command('clean [cwds...]', 'clean index.ts or entrypoint.ts file in working directory', (args) => yargOptionBuilder(args), (args) => __awaiter(this, void 0, void 0, function* () {
    const cwds = args['cwds'];
    if (!cwds) {
        console.log(chalk.default.magenta('Enter working directory, '));
        console.log(chalk.default.red('cti [working directory]'));
        process.exit(1);
    }
    if (typeof cwds === 'string') {
        const cleanCommand = new CleanCommandModule_1.CleanCommandModule();
        const options = CreateTsIndexOption_1.CreateTsIndexOption.cliOptionBuilder(args, cwds);
        yield cleanCommand.do(options);
    }
    if (typeof cwds !== 'string' && Array.isArray(cwds)) {
        return Promise.all(cwds
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const cleanCommand = new CleanCommandModule_1.CleanCommandModule();
            const options = CreateTsIndexOption_1.CreateTsIndexOption.cliOptionBuilder(args, cwd);
            return cleanCommand.do(options);
        }));
    }
}))
    .version(version, 'version', 'display version information')
    .help();
// tslint:disable-next-line
yargs.argv;
//# sourceMappingURL=cti.js.map